phonebookengines/contactsmodel/tsrc/cntplsql/src/t_cpcskeymap.h
changeset 46 efe85016a067
parent 24 0ba2181d7c28
--- a/phonebookengines/contactsmodel/tsrc/cntplsql/src/t_cpcskeymap.h	Fri Jun 11 13:29:23 2010 +0300
+++ b/phonebookengines/contactsmodel/tsrc/cntplsql/src/t_cpcskeymap.h	Wed Jun 23 18:02:44 2010 +0300
@@ -23,15 +23,15 @@
 #include <digia/eunit/eunitmacros.h>
 
 //  FORWARD DECLARATIONS
-class CPcsKeyMap;
+class C12keyKeyMap;
 
 //  CONSTANTS
 
 //  CLASS DEFINITION
 /**
  * Tester class for CPcsKeyMap.
  */
-NONSHARABLE_CLASS( UT_CPcsKeyMap ): public CEUnitTestSuiteClass
+NONSHARABLE_CLASS(UT_CPcsKeyMap): public CEUnitTestSuiteClass
     {
     public: // Constructors and destructors
 
@@ -59,14 +59,19 @@
     private: // Test methods
     
         void UT_NewLL();
-        void UT_GetNumericKeyStringL();
-        void UT_GetNumericKeyStringSeparatorL();
-        void UT_GetNumericKeyStringWithNumbersL();
-        void UT_GetNumericKeyStringWithSpecialCharactersL();
+        void UT_GetMappedStringL();
+        void UT_GetMappedStringSeparatorL();
+        void UT_GetMappedStringWithNumbersL();
+        void UT_GetMappedStringWithSpecialCharactersL();
+		void UT_GetMappedStringThaiLanguageOneCharL();
+        void UT_GetMappedStringThaiLanguageL();
+        void UT_GetMappedStringThaiLanguageEmptyResultL();
+        void UT_GetNumericLimitsL();
+		void UT_GetNumericLimitsLongInputL();
 
     private:    // Data
 
-        CPcsKeyMap* iKeyMap;
+        C12keyKeyMap* iKeyMap;
 
         EUNIT_DECLARE_TEST_TABLE;
     };
@@ -23,15 +23,15 @@
 //  CLASS DEFINITION
 /**
- * Tester class for CPcsKeyMap.
+ * Tester class for C12keyKeyMap.
  */